import { SubmitContactRequest as SubmitContactRequest$1, SubmitContactResponse as SubmitContactResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface SubmitContactRequest {
    /**
     * Contact's information.
     * To reconcile with an existing contact,
     * a phone or email must be provided,
     * or the current session identity must be attached to a contact or member.
     *
     * If no existing contact can be found,
     * a new contact is created with the specified information.
     *
     * <!--ONLY:REST-->
     * Required if there's no contextual identity or given `contactId`.
     * <!--END:ONLY:REST-->
     */
    info?: ContactInfo;
    /**
     * Pass through data, to be posted on Contact Submitted Domain Event (optional).
     * @maxLength 300
     */
    passThroughData?: string | null;
    /**
     * Existing Contact ID (optional).
     * Requires permission `CONTACTS.SUBMIT_WITH_OVERRIDES`
     * @format GUID
     */
    contactId?: string | null;
}
interface ContactInfo {
    /** Contact's first and last name. */
    name?: ContactName;
    /** Contact's email addresses. */
    emails?: ContactEmailsWrapper;
    /** Contact's phone numbers. */
    phones?: ContactPhonesWrapper;
    /** Contact's street addresses. */
    addresses?: ContactAddressesWrapper;
    /**
     * Contact's company name.
     * @maxLength 1000
     */
    company?: string | null;
    /**
     * Contact's job title.
     * @maxLength 1000
     */
    jobTitle?: string | null;
    /**
     * Birth date in `YYYY-MM-DD` format. For example, `2020-03-15`.
     * @format LOCAL_DATE
     */
    birthdate?: string | null;
    /**
     * Locale in
     * [IETF BCP 47 language tag](https://en.wikipedia.org/wiki/IETF_language_tag) format.
     * Typically, this is a lowercase 2-letter language code,
     * followed by a hyphen, followed by an uppercase 2-letter country code.
     * For example, `en-US` for U.S. English, and `de-DE` for Germany German.
     * @format LANGUAGE_TAG
     */
    locale?: string | null;
    /**
     * List of contact's labels.
     *
     * Labels are used to organize contacts. Labels can be
     * added and removed using Label Contact and Unlabel Contact, respectively.
     *
     * To view or manage contact labels, use the Labels API.
     */
    labelKeys?: LabelsWrapper;
    /**
     * Additional custom fields.
     *
     * Empty fields are not returned.
     */
    extendedFields?: ExtendedFieldsWrapper;
    /** Contact's profile picture. */
    picture?: ContactPicture;
}
interface ContactName {
    /**
     * Contact's first name.
     * @maxLength 1000
     */
    first?: string | null;
    /**
     * Contact's last name.
     * @maxLength 1000
     */
    last?: string | null;
}
interface ContactEmailsWrapper {
    /**
     * List of up to 50 email addresses.
     * @maxSize 50
     */
    items?: ContactEmail[];
}
interface ContactEmail {
    /**
     * Email ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Email type.
     *
     * `UNTAGGED` is shown as "Other" in the Contact List.
     */
    tag?: EmailTagWithLiterals;
    /**
     * Email address.
     * @minLength 1
     * @maxLength 320
     */
    email?: string;
    /**
     * Indicates whether this is the contact's primary email address.
     * When changing `primary` to `true` for an email,
     * the contact's other emails become `false`.
     * Changing the primary email of a contact also affects the subscription status to marketing emails that are decided based on the primary email.
     */
    primary?: boolean | null;
}
declare enum EmailTag {
    UNTAGGED = "UNTAGGED",
    MAIN = "MAIN",
    HOME = "HOME",
    WORK = "WORK"
}
/** @enumType */
type EmailTagWithLiterals = EmailTag | 'UNTAGGED' | 'MAIN' | 'HOME' | 'WORK';
interface ContactPhonesWrapper {
    /**
     * List of up to 50 phone numbers.
     * @maxSize 50
     */
    items?: ContactPhone[];
}
interface ContactPhone {
    /**
     * Phone ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Phone type.
     *
     * `UNTAGGED` is shown as "Other" in the Contact List.
     */
    tag?: PhoneTagWithLiterals;
    /**
     * [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
     * @format COUNTRY
     */
    countryCode?: string | null;
    /**
     * Phone number.
     * @minLength 1
     * @maxLength 50
     */
    phone?: string;
    /**
     * [ITU E.164-formatted](https://www.itu.int/rec/T-REC-E.164/)
     * phone number.
     * Automatically generated using `phone` and `countryCode`, pending both values are valid.
     * @readonly
     */
    e164Phone?: string | null;
    /**
     * Indicates whether this is the contact's primary phone number.
     * When changing `primary` to `true` for a phone,
     * the contact's `primary` field for other phones becomes `false`.
     * Changing the primary phone number also affects the subscription status to SMS messages that are decided based on the primary phone.
     */
    primary?: boolean | null;
}
declare enum PhoneTag {
    UNTAGGED = "UNTAGGED",
    MAIN = "MAIN",
    HOME = "HOME",
    MOBILE = "MOBILE",
    WORK = "WORK",
    FAX = "FAX"
}
/** @enumType */
type PhoneTagWithLiterals = PhoneTag | 'UNTAGGED' | 'MAIN' | 'HOME' | 'MOBILE' | 'WORK' | 'FAX';
interface ContactAddressesWrapper {
    /**
     * List of up to 50 addresses.
     * @maxSize 50
     */
    items?: ContactAddress[];
}
interface ContactAddress {
    /**
     * Street address ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Address type.
     * `UNTAGGED` is shown as "Other" in the Contact List.
     */
    tag?: AddressTagWithLiterals;
    /** Street address. */
    address?: Address;
}
declare enum AddressTag {
    UNTAGGED = "UNTAGGED",
    HOME = "HOME",
    WORK = "WORK",
    BILLING = "BILLING",
    SHIPPING = "SHIPPING"
}
/** @enumType */
type AddressTagWithLiterals = AddressTag | 'UNTAGGED' | 'HOME' | 'WORK' | 'BILLING' | 'SHIPPING';
/** Physical address */
interface Address extends AddressStreetOneOf {
    /** Street address object, with number and name in separate fields. */
    streetAddress?: StreetAddress;
    /**
     * Main address line, usually street and number, as free text.
     * @maxLength 1000
     */
    addressLine?: string | null;
    /**
     * 2-letter country code in an
     * [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) format.
     * @format COUNTRY
     */
    country?: string | null;
    /**
     * Code for a subdivision (such as state, prefecture, or province) in an
     * [ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2) format.
     * @maxLength 100
     */
    subdivision?: string | null;
    /**
     * City name.
     * @maxLength 1000
     */
    city?: string | null;
    /**
     * Postal or zip code.
     * @maxLength 100
     */
    postalCode?: string | null;
    /**
     * Free text providing more detailed address information,
     * such as apartment, suite, or floor.
     * @maxLength 1000
     */
    addressLine2?: string | null;
}
/** @oneof */
interface AddressStreetOneOf {
    /** Street address object, with number and name in separate fields. */
    streetAddress?: StreetAddress;
    /**
     * Main address line, usually street and number, as free text.
     * @maxLength 1000
     */
    addressLine?: string | null;
}
interface StreetAddress {
    /**
     * Street number.
     * @maxLength 100
     */
    number?: string;
    /**
     * Street name.
     * @maxLength 1000
     */
    name?: string;
}
interface LabelsWrapper {
    /**
     * List of contact label keys.
     *
     * Contact labels help categorize contacts. Label keys must exist to be added to the contact.
     * Contact labels can be created or retrieved with Find or Create Label or List Labels.
     * @maxSize 2000
     */
    items?: string[];
}
interface ExtendedFieldsWrapper {
    /**
     * Contact's extended fields,
     * where each key is the field key,
     * and each value is the field's value for the contact.
     *
     * To view and manage extended fields, use the Extended Fields API.
     */
    items?: Record<string, any>;
}
/** TEST contact picture description */
interface ContactPicture {
    /**
     * Image.
     * This can contain an image URL or a Wix Media image ID.
     */
    image?: Image;
}
interface Image {
    /**
     * WixMedia image ID.
     * This property is written by Wix when an image is uploaded to the Wix Media Manager.
     */
    id?: string;
    /** Image source: Either a Media Manager URL or external URL. */
    url?: string;
    /** Height of the original image. */
    height?: number;
    /** Width of the original image. */
    width?: number;
    /** Image alt text (optional). */
    altText?: string | null;
    /**
     * Image URL expiration date (optional).
     * @readonly
     */
    urlExpirationDate?: Date | null;
}
interface SubmitContactResponse {
    /**
     * ID of the contact that was found or created.
     * @format GUID
     */
    contactId?: string;
    /**
     * Identity type of the returned contact.
     *
     * - `CONTACT`: The returned contact ID belongs to a new or existing contact.
     * - `MEMBER`: The returned contact ID belongs to the currently logged-in site member.
     * - `NOT_AUTHENTICATED_MEMBER`: The returned contact ID belongs to a site member who is not currently logged in.
     */
    identityType?: IdentityTypeWithLiterals;
    /**
     * Indicates whether the contact was just created or already existed.
     *
     * If the contact was just created, returns `true`.
     * If it already existed, returns `false`.
     */
    newContact?: boolean;
}
declare enum IdentityType {
    UNKNOWN = "UNKNOWN",
    /** Existing or new contact */
    CONTACT = "CONTACT",
    /** Member is logged in, matching logic skipped */
    MEMBER = "MEMBER",
    /** Matching contact is a member, Merge logic won't be applied */
    NOT_AUTHENTICATED_MEMBER = "NOT_AUTHENTICATED_MEMBER"
}
/** @enumType */
type IdentityTypeWithLiterals = IdentityType | 'UNKNOWN' | 'CONTACT' | 'MEMBER' | 'NOT_AUTHENTICATED_MEMBER';

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function appendOrCreateContact(): __PublicMethodMetaInfo<'POST', {}, SubmitContactRequest$1, SubmitContactRequest, SubmitContactResponse$1, SubmitContactResponse>;

export { type __PublicMethodMetaInfo, appendOrCreateContact };
